==> org-lsst-sal-cccamera-2.2.7-sources.jar: org/lsst/sal/cccamera/telemetry/Quadbox_PDU_48VTelemetry.java <==
package org.lsst.sal.cccamera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_PDU_48VTelemetry extends CameraTelemetry {
  private final double board_T;

  private final double main_T;

  private final double main_V;

  private final double main_I;

  private final double fpga_T;

  private final double cryotel0_I;

  private final double cryotel0_V;

  private final double cryotel1_I;

  private final double cryotel1_V;

  private final double cryotel2_I;

  private final double cryotel2_V;

  private final double reb_bulk_I;

  private final double reb_bulk_V;

  public Quadbox_PDU_48VTelemetry(double board_T, double main_T, double main_V, double main_I,
      double fpga_T, double cryotel0_I, double cryotel0_V, double cryotel1_I, double cryotel1_V,
      double cryotel2_I, double cryotel2_V, double reb_bulk_I, double reb_bulk_V) {
    this.board_T = board_T;
    this.main_T = main_T;
    this.main_V = main_V;
    this.main_I = main_I;
    this.fpga_T = fpga_T;
    this.cryotel0_I = cryotel0_I;
    this.cryotel0_V = cryotel0_V;
    this.cryotel1_I = cryotel1_I;
    this.cryotel1_V = cryotel1_V;
    this.cryotel2_I = cryotel2_I;
    this.cryotel2_V = cryotel2_V;
    this.reb_bulk_I = reb_bulk_I;
    this.reb_bulk_V = reb_bulk_V;
  }

  public double getBoard_T() {
    return board_T;
  }

  public double getMain_T() {
    return main_T;
  }

  public double getMain_V() {
    return main_V;
  }

  public double getMain_I() {
    return main_I;
  }

  public double getFpga_T() {
    return fpga_T;
  }

  public double getCryotel0_I() {
    return cryotel0_I;
  }

  public double getCryotel0_V() {
    return cryotel0_V;
  }

  public double getCryotel1_I() {
    return cryotel1_I;
  }

  public double getCryotel1_V() {
    return cryotel1_V;
  }

  public double getCryotel2_I() {
    return cryotel2_I;
  }

  public double getCryotel2_V() {
    return cryotel2_V;
  }

  public double getReb_bulk_I() {
    return reb_bulk_I;
  }

  public double getReb_bulk_V() {
    return reb_bulk_V;
  }

  @Override
  public String toString() {
    return "Quadbox_PDU_48VTelemetry{" + "board_T=" + board_T +", main_T=" + main_T +
        ", main_V=" + main_V +", main_I=" + main_I +", fpga_T=" + fpga_T +
        ", cryotel0_I=" + cryotel0_I +", cryotel0_V=" + cryotel0_V +", cryotel1_I=" + cryotel1_I +
        ", cryotel1_V=" + cryotel1_V +", cryotel2_I=" + cryotel2_I +", cryotel2_V=" + cryotel2_V +
        ", reb_bulk_I=" + reb_bulk_I +", reb_bulk_V=" + reb_bulk_V +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double board_T;

    private double main_T;

    private double main_V;

    private double main_I;

    private double fpga_T;

    private double cryotel0_I;

    private double cryotel0_V;

    private double cryotel1_I;

    private double cryotel1_V;

    private double cryotel2_I;

    private double cryotel2_V;

    private double reb_bulk_I;

    private double reb_bulk_V;

    private Builder() {
    }

    public Builder board_T(double board_T) {
      this.board_T = board_T;
      return this;
    }

    public Builder main_T(double main_T) {
      this.main_T = main_T;
      return this;
    }

    public Builder main_V(double main_V) {
      this.main_V = main_V;
      return this;
    }

    public Builder main_I(double main_I) {
      this.main_I = main_I;
      return this;
    }

    public Builder fpga_T(double fpga_T) {
      this.fpga_T = fpga_T;
      return this;
    }

    public Builder cryotel0_I(double cryotel0_I) {
      this.cryotel0_I = cryotel0_I;
      return this;
    }

    public Builder cryotel0_V(double cryotel0_V) {
      this.cryotel0_V = cryotel0_V;
      return this;
    }

    public Builder cryotel1_I(double cryotel1_I) {
      this.cryotel1_I = cryotel1_I;
      return this;
    }

    public Builder cryotel1_V(double cryotel1_V) {
      this.cryotel1_V = cryotel1_V;
      return this;
    }

    public Builder cryotel2_I(double cryotel2_I) {
      this.cryotel2_I = cryotel2_I;
      return this;
    }

    public Builder cryotel2_V(double cryotel2_V) {
      this.cryotel2_V = cryotel2_V;
      return this;
    }

    public Builder reb_bulk_I(double reb_bulk_I) {
      this.reb_bulk_I = reb_bulk_I;
      return this;
    }

    public Builder reb_bulk_V(double reb_bulk_V) {
      this.reb_bulk_V = reb_bulk_V;
      return this;
    }

    public Quadbox_PDU_48VTelemetry build() {
      return new Quadbox_PDU_48VTelemetry(board_T, main_T, main_V, main_I, fpga_T, cryotel0_I, cryotel0_V, cryotel1_I, cryotel1_V, cryotel2_I, cryotel2_V, reb_bulk_I, reb_bulk_V);
    }
  }
}

==> org-lsst-sal-cccamera-2.6.4-sources.jar: org/lsst/sal/cccamera/telemetry/Quadbox_PDU_48VTelemetry.java <==
package org.lsst.sal.cccamera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_PDU_48VTelemetry extends CameraTelemetry {
  private final double board_T;

  private final double cryotel0_I;

  private final double cryotel0_V;

  private final double cryotel1_I;

  private final double cryotel1_V;

  private final double cryotel2_I;

  private final double cryotel2_V;

  private final double fpga_T;

  private final double main_I;

  private final double main_T;

  private final double main_V;

  private final double reb_BULK_I;

  private final double reb_BULK_V;

  public Quadbox_PDU_48VTelemetry(double board_T, double cryotel0_I, double cryotel0_V,
      double cryotel1_I, double cryotel1_V, double cryotel2_I, double cryotel2_V, double fpga_T,
      double main_I, double main_T, double main_V, double reb_BULK_I, double reb_BULK_V) {
    this.board_T = board_T;
    this.cryotel0_I = cryotel0_I;
    this.cryotel0_V = cryotel0_V;
    this.cryotel1_I = cryotel1_I;
    this.cryotel1_V = cryotel1_V;
    this.cryotel2_I = cryotel2_I;
    this.cryotel2_V = cryotel2_V;
    this.fpga_T = fpga_T;
    this.main_I = main_I;
    this.main_T = main_T;
    this.main_V = main_V;
    this.reb_BULK_I = reb_BULK_I;
    this.reb_BULK_V = reb_BULK_V;
  }

  public double getBoard_T() {
    return board_T;
  }

  public double getCryotel0_I() {
    return cryotel0_I;
  }

  public double getCryotel0_V() {
    return cryotel0_V;
  }

  public double getCryotel1_I() {
    return cryotel1_I;
  }

  public double getCryotel1_V() {
    return cryotel1_V;
  }

  public double getCryotel2_I() {
    return cryotel2_I;
  }

  public double getCryotel2_V() {
    return cryotel2_V;
  }

  public double getFpga_T() {
    return fpga_T;
  }

  public double getMain_I() {
    return main_I;
  }

  public double getMain_T() {
    return main_T;
  }

  public double getMain_V() {
    return main_V;
  }

  public double getReb_BULK_I() {
    return reb_BULK_I;
  }

  public double getReb_BULK_V() {
    return reb_BULK_V;
  }

  @Override
  public String toString() {
    return "Quadbox_PDU_48VTelemetry{" + "board_T=" + board_T +", cryotel0_I=" + cryotel0_I +
        ", cryotel0_V=" + cryotel0_V +", cryotel1_I=" + cryotel1_I +", cryotel1_V=" + cryotel1_V +
        ", cryotel2_I=" + cryotel2_I +", cryotel2_V=" + cryotel2_V +", fpga_T=" + fpga_T +
        ", main_I=" + main_I +", main_T=" + main_T +", main_V=" + main_V +
        ", reb_BULK_I=" + reb_BULK_I +", reb_BULK_V=" + reb_BULK_V +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double board_T;

    private double cryotel0_I;

    private double cryotel0_V;

    private double cryotel1_I;

    private double cryotel1_V;

    private double cryotel2_I;

    private double cryotel2_V;

    private double fpga_T;

    private double main_I;

    private double main_T;

    private double main_V;

    private double reb_BULK_I;

    private double reb_BULK_V;

    private Builder() {
    }

    public Builder board_T(double board_T) {
      this.board_T = board_T;
      return this;
    }

    public Builder cryotel0_I(double cryotel0_I) {
      this.cryotel0_I = cryotel0_I;
      return this;
    }

    public Builder cryotel0_V(double cryotel0_V) {
      this.cryotel0_V = cryotel0_V;
      return this;
    }

    public Builder cryotel1_I(double cryotel1_I) {
      this.cryotel1_I = cryotel1_I;
      return this;
    }

    public Builder cryotel1_V(double cryotel1_V) {
      this.cryotel1_V = cryotel1_V;
      return this;
    }

    public Builder cryotel2_I(double cryotel2_I) {
      this.cryotel2_I = cryotel2_I;
      return this;
    }

    public Builder cryotel2_V(double cryotel2_V) {
      this.cryotel2_V = cryotel2_V;
      return this;
    }

    public Builder fpga_T(double fpga_T) {
      this.fpga_T = fpga_T;
      return this;
    }

    public Builder main_I(double main_I) {
      this.main_I = main_I;
      return this;
    }

    public Builder main_T(double main_T) {
      this.main_T = main_T;
      return this;
    }

    public Builder main_V(double main_V) {
      this.main_V = main_V;
      return this;
    }

    public Builder reb_BULK_I(double reb_BULK_I) {
      this.reb_BULK_I = reb_BULK_I;
      return this;
    }

    public Builder reb_BULK_V(double reb_BULK_V) {
      this.reb_BULK_V = reb_BULK_V;
      return this;
    }

    public Quadbox_PDU_48VTelemetry build() {
      return new Quadbox_PDU_48VTelemetry(board_T, cryotel0_I, cryotel0_V, cryotel1_I, cryotel1_V, cryotel2_I, cryotel2_V, fpga_T, main_I, main_T, main_V, reb_BULK_I, reb_BULK_V);
    }
  }
}
